@@ -293,7 +293,8 @@ def PySconsSetup(args=ARGUMENTS, tools=['default', PYTOOL()]):
     try: basename = args["temp"] 
     except: basename = None
 
-    env.SConsignFile(basename + ".sconsign")
+    bn = os.path.split(basename)
+    env.SConsignFile(os.path.join([".."] * (len(bn) - 1) + bn + [".sconsign"]))
 
     ftargets = [t + ".force" for t in targets]
     if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
